==> octave2.1_2.1.57.orig.tar.gz: octave-2.1.57/src/oct-strstrm.cc <==
/*

Copyright (C) 1996, 1997 John W. Eaton

This file is part of Octave.

Octave is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option) any
later version.

Octave is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with Octave; see the file COPYING.  If not, write to the Free
Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "oct-strstrm.h"

// Position a stream at OFFSET relative to ORIGIN.

int
octave_base_strstream::seek (long offset, int origin)
{
  error ("fseek: invalid operation");
  return -1;
}

// Return current stream position.

long
octave_base_strstream::tell (void)
{
  error ("ftell: invalid operation");
  return -1;
}

octave_stream
octave_istrstream::create (const char *data, std::ios::openmode arg_md,
			   oct_mach_info::float_format flt_fmt)
{
  return octave_stream (new octave_istrstream (data, arg_md, flt_fmt));
}

octave_stream
octave_istrstream::create (const std::string& data, std::ios::openmode arg_md,
			   oct_mach_info::float_format flt_fmt)
{
  return octave_stream (new octave_istrstream (data, arg_md, flt_fmt));
}

octave_stream
octave_ostrstream::create (std::ios::openmode arg_md,
			   oct_mach_info::float_format flt_fmt)
{
  return octave_stream (new octave_ostrstream (arg_md, flt_fmt));
}

/*
;;; Local Variables: ***
;;; mode: C++ ***
;;; End: ***
*/

==> octave2.1_2.1.69.orig.tar.gz: octave-2.1.69/src/oct-strstrm.cc <==
/*

Copyright (C) 1996, 1997 John W. Eaton

This file is part of Octave.

Octave is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 2, or (at your option) any
later version.

Octave is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License
along with Octave; see the file COPYING.  If not, write to the Free
Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "oct-strstrm.h"

// Position a stream at OFFSET relative to ORIGIN.

int
octave_base_strstream::seek (long, int)
{
  error ("fseek: invalid operation");
  return -1;
}

// Return current stream position.

long
octave_base_strstream::tell (void)
{
  error ("ftell: invalid operation");
  return -1;
}

octave_stream
octave_istrstream::create (const char *data, std::ios::openmode arg_md,
			   oct_mach_info::float_format flt_fmt)
{
  return octave_stream (new octave_istrstream (data, arg_md, flt_fmt));
}

octave_stream
octave_istrstream::create (const std::string& data, std::ios::openmode arg_md,
			   oct_mach_info::float_format flt_fmt)
{
  return octave_stream (new octave_istrstream (data, arg_md, flt_fmt));
}

octave_stream
octave_ostrstream::create (std::ios::openmode arg_md,
			   oct_mach_info::float_format flt_fmt)
{
  return octave_stream (new octave_ostrstream (arg_md, flt_fmt));
}

/*
;;; Local Variables: ***
;;; mode: C++ ***
;;; End: ***
*/
